@@ -13,11 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 r"""
-Routines to import arrays
--------------------------
-
-Basic Concepts
-^^^^^^^^^^^^^^
+Importers
+---------
 
 Here we provide a collection of several importers to conveniently
 create EADF objects from various data formats. For this purpose we
@@ -26,9 +23,6 @@ intermediate formats, which facilitate the construction of importers,
 since for these handshake formats we already provide tested conversion
 routines to the internal data format.
 
-Handshake Formats
-^^^^^^^^^^^^^^^^^
-
 For these formats there are readily available and tested importers. See
 the respective importer methods for further details.
 
